==> haskell-data-checked-0.3-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-8QGKNecKFkc5mF4RPtwLdy
key:                  data-checked-0.3-8QGKNecKFkc5mF4RPtwLdy
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties 
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  fc5ff2bb277b9230fdaf2e0fb8863f6e
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-9.0.2/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.2/data-checked-0.3
hs-libraries:         HSdata-checked-0.3-8QGKNecKFkc5mF4RPtwLdy
depends:              base-4.15.1.0 deepseq-1.4.5.0
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-data-checked-0.3-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-data-checked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 data-checked
version:              0.3
visibility:           public
id:                   data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
key:                  data-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
license:              BSD-3-Clause
copyright:            2013 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
maintainer:           Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
author:               Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability:            experimental
homepage:             https://github.com/mvv/data-checked
synopsis:             Type-indexed runtime-checked properties 
description:
    This package provides a (phantom) type-indexed newtype evidence-wrapper for
    values that are checked to satisfy the property associated with the type.

category:             Data
abi:                  6b1e9fdfffca2aca9b890cd5152b0a39
exposed:              True
exposed-modules:      Data.Checked Data.Checked.Strict
import-dirs:          /usr/lib/ghc-9.2.8/site-local/data-checked-0.3
library-dirs:         /usr/lib/ghc-9.2.8/site-local/data-checked-0.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-data-checked
hs-libraries:         HSdata-checked-0.3-AoDRRseaqKNJUvFhUEXFZw
depends:              base-4.16.4.0 deepseq-1.4.6.1
haddock-interfaces:
    /usr/share/doc/haskell-data-checked/html/data-checked.haddock

haddock-html:         /usr/share/doc/haskell-data-checked/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
